Circle

Struct Circle 

pub struct Circle<P: Pixel> {
    pub position: (usize, usize),
    pub color: P,
    pub radius: u32,
    pub filled: bool,
    pub thickness: u32,
}
A circle shape that can be drawn onto an image. Can be either filled or drawn as an outline with a specified thickness. The color is specified in RGBA8 format.

Fields

position: (usize, usize)

Center of the circle (x, y)

color: P

Color as a struct that implements Pixel (like [Rgba], [Luma])

radius: u32

Radius in pixels

filled: bool

Fill the shape (true) or draw outline (false)

thickness: u32

Outline thickness (only used when filled = false)