Image

Struct Image 

pub struct Image<P: Pixel> { /* private fields */ }
Image struct represents an image with pixel data of type P where P implements the Pixel trait.

Implementations

Source

impl<P> Image<P>
where P: Pixel,

pub fn pixels(&self) -> PixelIter<'_, P>

pub fn pixels_mut(&mut self) -> PixelIterMut<'_, P>

pub fn par_pixels(&self) -> Iter<'_, P>

pub fn par_pixels_mut(&mut self) -> IterMut<'_, P>

Source

impl<P> Image<P>
where P: Pixel,

pub fn new(width: usize, height: usize) -> Self

Creates a new empty Image instance with the specified width and height.

pub fn open<Pth: AsRef<Path>>(path: Pth) -> Result<Self>

Creates a new Image instance from the given path.

pub fn save<Pth: AsRef<Path>>(&self, path: Pth) -> Result<()>

Saves the image to the specified path. File format is determined by the file extension. See image::ImageBuffer::save for more details.

pub fn display(&self, title: &str) -> Result<()>

Opens an Image instance and displays it in a window.

pub fn get_pixel(&self, position: (usize, usize)) -> Result<&P>

Returns a reference to the pixel data at the specified position. Returns an error if the position is out of bounds.

pub fn set_pixel(&mut self, position: (usize, usize), color: P) -> Result<()>

Sets the pixel at the specified position to the given color. Colors are of type P, which implements the Pixel trait. Returns an error if the position is out of bounds.

pub fn draw<D: Drawable<P>>(&mut self, shape: D) -> Result<()>

Draws a shape on the image. The shape must implement the Drawable trait.

pub fn dimensions(&self) -> (usize, usize)

Returns the dimensions of the image as a tuple (width, height).

pub fn is_empty(&self) -> bool

Returns true if the image is empty

pub fn to_rgba8(&self) -> Image<Rgba<u8>>

Convert the image to RGBA8 format.