Modules
- drawing
- img
- This module provides the
Imagestruct for handling images with generic pixel data. It includes functionality for loading, saving, displaying images, and manipulating pixel data. The pixel data is represented by a type that implements thePixeltrait, allowing for flexible support of different pixel formats like Rgba and Luma, with u8, u16, f32 (for now).