pub struct Circle<P: Pixel> {
pub position: (usize, usize),
pub color: P,
pub radius: u32,
pub filled: bool,
pub thickness: u32,
}Expand description
A circle shape that can be drawn onto an image. Can be either filled or drawn as an outline with a specified thickness. The color is specified in RGBA8 format.
Fields
position: (usize, usize)Center of the circle (x, y)
color: PColor as a struct that implements Pixel (like [Rgba], [Luma])
radius: u32Radius in pixels
filled: boolFill the shape (true) or draw outline (false)
thickness: u32Outline thickness (only used when filled = false)