Struct Image

pub struct Image { /* private fields */ }
A struct that provides image handling functionality

Examples

// Open and display an image
use glance_core::img::Image;

if let Ok(img) = Image::open("path/to/image.jpg") {
    let _ = img.display("Example Image");
}

Implementations

Source

impl Image

pub fn pixels(&self) -> PixelIter<'_>

pub fn pixels_mut(&mut self) -> PixelIterMut<'_>

pub fn par_pixels( &self, ) -> impl ParallelIterator<Item = (usize, usize, [u8; 4])>

pub fn par_pixels_mut( &mut self, ) -> impl ParallelIterator<Item = (usize, usize, &mut [u8; 4])>

Source

impl Image

pub fn open<P: AsRef<Path>>(path: P) -> Result<Self>

Opens an image from the given path.

Returns an error if the file does not exist or cannot be decoded. Supports all formats recognized by the image crate.

pub fn save<P: AsRef<Path>>(&self, path: P) -> Result<()>

Saves an image to the given path

Returns an error if the file cannot be created or buffer is invalid. Format is recognized from file extension (see image::ImageBuffer::save for more info).

pub fn new(width: u32, height: u32, data: Vec<u8>) -> Result<Self>

Creates a new Image from width, height, and a data buffer (must be RGBA, widthheight4 bytes).

pub fn display(&self, title: &str) -> Result<()>

Displays the image (as RGBA8) in a window until Escape is pressed. Returns an error if the window cannot be created. The window runs at 1 FPS to minimize CPU usage. Uses minifb for cross-platform windowing.

pub fn get_pixel(&self, position: [u32; 2]) -> Result<[u8; 4]>

Gets the color of a pixel. Top left is treated as origin. Right is positive x, down is positive y.

pub fn set_pixel(&mut self, position: [u32; 2], color: [u8; 4]) -> Result<()>

Sets a pixel to the given color. Top left is treated as origin, x-axis goes horizontally.

pub fn alpha_blend_pixel( &mut self, position: [u32; 2], color: [u8; 4], ) -> Result<()>

Linearly interpolate a pixel color with the given color

pub fn draw<D: Drawable>(&mut self, shape: D) -> Result<()>

Draw a shape (any struct that implements the [drawing::traits::Drawable] trait)

pub fn is_empty(&self) -> bool

Returns true if the image contains no pixel data.

pub fn dimensions(&self) -> [u32; 2]

Returns the image dimensions as (width, height).